module.exports = defineTest({
	description: 'supports tree-shaking with nullish-coalescing'
});
